summaryrefslogtreecommitdiff
path: root/spec/bundler/support/artifice/fail.rb
diff options
context:
space:
mode:
authorDavid Rodríguez <deivid.rodriguez@riseup.net>2023-01-29 21:28:29 +0100
committerHiroshi SHIBATA <hsbt@ruby-lang.org>2023-12-13 12:16:55 +0900
commit90317472e87692fff1c864d129d60130dc3bab2c (patch)
tree698f2aa5911cc1a4512c9019b6e785495c47d3bc /spec/bundler/support/artifice/fail.rb
parentce924ce1fb029f19fd34a43f2012a485f4f62b53 (diff)
[rubygems/rubygems] Use vendored net-http in Bundler
https://github.com/rubygems/rubygems/commit/0d758e8926
Diffstat (limited to 'spec/bundler/support/artifice/fail.rb')
-rw-r--r--spec/bundler/support/artifice/fail.rb10
1 files changed, 5 insertions, 5 deletions
diff --git a/spec/bundler/support/artifice/fail.rb b/spec/bundler/support/artifice/fail.rb
index a6a8552893..8822e5b8e2 100644
--- a/spec/bundler/support/artifice/fail.rb
+++ b/spec/bundler/support/artifice/fail.rb
@@ -1,11 +1,11 @@
# frozen_string_literal: true
-require "net/http"
+require "bundler/vendored_net_http"
-class Fail < Net::HTTP
- # Net::HTTP uses a @newimpl instance variable to decide whether
+class Fail < Gem::Net::HTTP
+ # Gem::Net::HTTP uses a @newimpl instance variable to decide whether
# to use a legacy implementation. Since we are subclassing
# Net::HTTP, we must set it
@newimpl = true
def request(req, body = nil, &block)
@@ -23,5 +23,5 @@ end
require_relative "helpers/artifice"
# Replace Net::HTTP with our failing subclass
Artifice.replace_net_http(::Fail)
@@ -1,11 +1,11 @@
# to use a legacy implementation. Since we are subclassing
- # Net::HTTP, we must set it
+ # Gem::Net::HTTP, we must set it
def request(req, body = nil, &block)
@@ -23,5 +23,5 @@ end
require_relative "helpers/artifice"
-# Replace Net::HTTP with our failing subclass
+# Replace Gem::Net::HTTP with our failing subclass
Artifice.replace_net_http(::Fail)